#include <avr/io.h>
#include <stdbool.h>
#include <avr/interrupt.h>
#include <stdio.h>
#include <stdlib.h>

#include "./keys.h"

void InitKeys(){
	//Schalter am PORTC auf Eingang, Pullups aktiv
	PORTC = (1 << UP) | (1 << DOWN) | (1 << LEFT) | (1 << RIGHT) | (1 << OK) | (1 << ONOFF);
	DDRC = 0x00;
}

uint8_t Debounced_State; // Debounced state of the switches
uint8_t State[MAX_CHECKS]; // Array that maintains bounce status
uint8_t Key_Press;
uint8_t Index; // Pointer into State

void GetKey(){
	uint8_t i;
	//uint8_t j;
	uint8_t Key_Changed = 0xff;
	//j=0xff;
	for(i=0; i<MAX_CHECKS;i++){
		Key_Changed = Key_Changed & State[i];
		//j=j & State[i];
	}
	//Key_Changed = Debounced_State ^j;
	Key_Changed ^=Debounced_State;
	Debounced_State ^= Key_Changed;
	Key_Press |= Debounced_State & Key_Changed;
}

// Service routine called by a timer interrupt
void DebounceSwitch(){
	uint8_t result;
	result =  (TasterPins);
	State[Index]=~result;
	++Index;
	if(Index>=MAX_CHECKS){
		Index=0;
		GetKey();
	}
}

///////////////////////////////////////////////////////////////////
//
// check if a key has been pressed. Each pressed key is reported
// only once
//
uint8_t get_key_press( uint8_t key_mask )
{
  cli();                                          // read and clear atomic !
  key_mask &= Key_Press;                          // read key(s)
  Key_Press ^= key_mask;                          // clear key(s)
  sei();
  return key_mask;
}


///////////////////////////////////////////////////////////////////
//
uint8_t get_key_short( uint8_t key_mask )
{
  cli();                                          // read key state and key press atomic !
  return get_key_press( ~Debounced_State & key_mask );
}



